=====
HCUP Hachoir: Staging module
=====

Part of the Django-HCUP Hachoir set of Python packages. Provides functionality roughly corresponding to the "staging" phase of a data warehouse, but focused exclusively on handling data from the United States Healthcare Cost and Utilization Project (HCUP). More information about HCUP is available online at https://www.hcup-us.ahrq.gov/.

Quick start
-----------

0. Make sure you have djhcup-core properly installed. djhcup_staging depends on functionality provided through djhcup-core, and will not be accessible through the web server without it.

1. Add "djhcup_staging" to your INSTALLED_APPS setting like this::

      INSTALLED_APPS = (
          ...
          'djhcup_staging',
      )

2. N.B., you do not need to separately modify your Django urls.py for djhcup_staging to work. Once djhcup-core is installed, it will automatically handle urls for djhcup_staging and its sister modules.

3. Run `python manage.py syncdb` to create the djhcup_staging models. Or, if using South, migrate forward to build database objects for this package's models.

4. Start your server per normal (for test servers, use `python manage.py runserver`).
